UNMODIFIED_INIT = "__unmodified__init__"
UNMODIFIED_NEW = "__unmodified__new__"

DONT_ADD_TO_KNOWN = "__dont_add_to_known__"

KWARGS_VALUE = "_kwargs"

ALREADY_SEEN_TYPES = "__already_seen_types__"
